pub struct ResourcePoolStatusRequest {
pub metadata: ObjectMeta,
pub spec: ResourcePoolStatusRequestSpec,
pub status: Option<ResourcePoolStatusRequestStatus>,
}Expand description
ResourcePoolStatusRequest triggers a one-time calculation of resource pool status based on the provided filters. Once status is set, the request is considered complete and will not be reprocessed. Users should delete and recreate requests to get updated information.
Fields
metadata: ObjectMetaStandard object metadata
spec: ResourcePoolStatusRequestSpecSpec defines the filters for which pools to include in the status. The spec is immutable once created.
status: Option<ResourcePoolStatusRequestStatus>Status is populated by the controller with the calculated pool status. When status is non-nil, the request is considered complete and the entire object becomes immutable.