pub struct ResourcePoolStatusRequestSpec {
pub driver: String,
pub limit: Option<i32>,
pub pool_name: Option<String>,
}Expand description
ResourcePoolStatusRequestSpec defines the filters for the pool status request.
Fields
driver: StringDriver specifies the DRA driver name to filter pools. Only pools from ResourceSlices with this driver will be included. Must be a DNS subdomain (e.g., “gpu.example.com”).
limit: Option<i32>Limit optionally specifies the maximum number of pools to return in the status. If more pools match the filter criteria, the response will be truncated (i.e., len(status.pools) < status.poolCount).
Default: 100 Minimum: 1 Maximum: 1000
pool_name: Option<String>PoolName optionally filters to a specific pool name. If not specified, all pools from the specified driver are included. When specified, must be a non-empty valid resource pool name (DNS subdomains separated by “/”).