pub struct DeviceAttribute {
pub bool: Option<bool>,
pub bools: Option<Vec<bool>>,
pub int: Option<i64>,
pub ints: Option<Vec<i64>>,
pub string: Option<String>,
pub strings: Option<Vec<String>>,
pub version: Option<String>,
pub versions: Option<Vec<String>>,
}Expand description
DeviceAttribute must have exactly one field set.
Fields
bool: Option<bool>BoolValue is a true/false value.
bools: Option<Vec<bool>>BoolValues is a non-empty list of true/false values.
int: Option<i64>IntValue is a number.
ints: Option<Vec<i64>>IntValues is a non-empty list of numbers.
This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.
string: Option<String>StringValue is a string. Must not be longer than 64 characters.
strings: Option<Vec<String>>StringValues is a non-empty list of strings. Each string must not be longer than 64 characters.
This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.
version: Option<String>VersionValue is a semantic version according to semver.org spec 2.0.0. Must not be longer than 64 characters.
versions: Option<Vec<String>>VersionValues is a non-empty list of semantic versions according to semver.org spec 2.0.0. Each version string must not be longer than 64 characters.
This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.